; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a Taylor Diagram plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "taylor_diagram.pro" and run it like this::
;       IDL> .RUN taylor_diagram
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Taylor_Diagram
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   labels = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H']            
   stddev = [1.4, 0.9, 1.0, 1.272, 1.1, 0.95, 1.08, 0.5]        
   correlation = [0.8, 0.9, 0.65, 0.74, 0.91, 0.98, 0.85, 0.35] 
   ref_std = 1.0                                                
   stddev_max = 1.5   
   
   ; Draw the Taylor Diagram.                                          
   cgTaylorDiagram, stddev, correlation, REF_STDDEV=ref_std, STDDEV_MAX=stddev_max, $
       RMS_INCREMENT=0.25, RMS_FORMAT='(F0.2)', LABELS=labels       
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Taylor_Diagram
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Taylor_Diagram', WTitle='Taylor Diagram in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'taylor_diagram.ps'
  Taylor_Diagram
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'taylor_diagram.ps', /PNG, Width=600

END